@@ -173,6 +173,13 @@ class WebElement(BaseWebElement):
             # Check if the "active" CSS class is applied to an element.
             is_active = "active" in target_element.get_attribute("class")
         """
+
+        warnings.warn(
+            "using WebElement.get_attribute() has been deprecated. Please use get_dom_attribute() instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+
         if getAttribute_js is None:
             _load_js()
         attribute_value = self.parent.execute_script(
@@ -404,16 +411,7 @@ class WebElement(BaseWebElement):
 
         :rtype: WebElement
         """
-        if by == By.ID:
-            by = By.CSS_SELECTOR
-            value = f'[id="{value}"]'
-        elif by == By.CLASS_NAME:
-            by = By.CSS_SELECTOR
-            value = f".{value}"
-        elif by == By.NAME:
-            by = By.CSS_SELECTOR
-            value = f'[name="{value}"]'
-
+        by, value = self._parent.locator_converter.convert(by, value)
         return self._execute(Command.FIND_CHILD_ELEMENT, {"using": by, "value": value})["value"]
 
     def find_elements(self, by=By.ID, value=None) -> List[WebElement]:
@@ -426,16 +424,7 @@ class WebElement(BaseWebElement):
 
         :rtype: list of WebElement
         """
-        if by == By.ID:
-            by = By.CSS_SELECTOR
-            value = f'[id="{value}"]'
-        elif by == By.CLASS_NAME:
-            by = By.CSS_SELECTOR
-            value = f".{value}"
-        elif by == By.NAME:
-            by = By.CSS_SELECTOR
-            value = f'[name="{value}"]'
-
+        by, value = self._parent.locator_converter.convert(by, value)
         return self._execute(Command.FIND_CHILD_ELEMENTS, {"using": by, "value": value})["value"]
 
     def __hash__(self) -> int:
